@@ -10,7 +10,7 @@ class ContentNode(template.Node):
     def __init__(self, nodelist, parser, token):
         bits = token.split_contents()
         if len(bits) != 4 or bits[-2] != 'as':
-            raise TemplateSyntaxError(self.error_msg)
+            raise template.TemplateSyntaxError(self.error_msg)
         self.identifier = parser.compile_filter(bits[1])
         self.as_var = bits[-1]
         self.nodelist = nodelist
@@ -18,8 +18,9 @@ class ContentNode(template.Node):
     def render(self, context):
         identifier = self.identifier.resolve(context)
         try:
+            active = context['active']
             content = babylon.get('PageContentCache', identifier,
-                context['active'])
+                active=context['active'])
             context.push()
             context[self.as_var] = content
             output = self.nodelist.render(context)
